####################################################################################################

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.ticker as ticker

####################################################################################################

# V A Hz
data_unloaded = (
    (12.1, 0.56,  1.4),
    (14.0, 0.56,  3.1),
    (15.0, 0.56,  3.7),
    (16.0, 0.58,  4.5),
    (20.0, 0.63,  6.9),
    (22.5, 0.65,  8.5),
    (25.0, 0.65, 10.3),
    (32.0, 0.68, 14.5),
    (32.5, 0.65, 16.6),
    (40.0, 0.70, 20.8),
    (50.0, 0.72, 28.0),
    (63.0, 0.73, 38.0),
)

####################################################################################################

data = np.array(data)
print(data, data.shape)
volt_array = data[:,0]
current_array = data[:,1]
frequency_array = data[:,2]
rpm_array = frequency_array * 60

slope, cst = np.polyfit(volt_array, rpm_array, 1)

####################################################################################################

fig, ax = plt.subplots(constrained_layout=True)

def axis1to2(x):
    return x

def axis2to1(x):
    return x

ax.plot(volt_array, current_array*1000, 'o-', label=r'I')
ax.plot(volt_array, rpm_array, 'o-', label=r'RPM')
ax.plot(volt_array, slope*volt_array + cst, '--k')

ax.xaxis.set_major_locator(ticker.MultipleLocator(5))
ax.yaxis.set_major_locator(ticker.MultipleLocator(500))
ax.xaxis.set_minor_locator(ticker.MultipleLocator(1))
ax.yaxis.set_minor_locator(ticker.MultipleLocator(100))
ax.grid(True, color='k', linestyle='-', linewidth=1)
ax.xaxis.grid(True, which='minor')
ax.yaxis.grid(True, which='minor')
ax.set_xlabel(r'$U\ [V]$')
ax.set_ylabel(r'$RPM\ [min^{-1}]$')
yaxis2 = ax.secondary_yaxis('right', functions=(axis1to2, axis2to1))
yaxis2.set_ylabel(r'$I\ [mA]$')
# print('poly:', slope, cst)
ax.text(41, 1100, r'RPM = {:.1f} U + {:.1f}'.format((slope), cst), fontsize=12)
ax.legend()
ax.set_title(r'DC Singer Motor')

ax.axvspan(15, 20, alpha=0.5, color='red')
ax.text(15, 1100, r'$\mathrm{Start}\ U > 18\,V$', fontsize=12)

plt.show()
